aboutsummaryrefslogtreecommitdiff
path: root/src/hyper/macro.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/hyper/macro.c')
-rw-r--r--src/hyper/macro.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/hyper/macro.c b/src/hyper/macro.c
index 596506c6..b68c87b0 100644
--- a/src/hyper/macro.c
+++ b/src/hyper/macro.c
@@ -268,7 +268,7 @@ parse_macro(void)
return 1;
else {
fprintf(stderr,
- "parse_macro: Tried to pop an empty paramter stack\n");
+ "parse_macro: Tried to pop an empty parameter stack\n");
longjmp(jmpbuf, 1);
}
}
@@ -322,7 +322,7 @@ get_parameter_strings(int number,char * macro_name)
*buffer_pntr++ = c;
break;
case '#':
/* uh oh, I have a paramter reference inside a paramter */
/* get the number */
if (parameters == NULL) {
*buffer_pntr++ = c;
@@ -347,7 +347,7 @@ get_parameter_strings(int number,char * macro_name)
pnum_chars[pc] = '\0';
pnum = atoi(pnum_chars);
pc = 0;
/* Now copy the paramter */
while ((parameters->list)[pnum - 1][pc] != '\0')
*buffer_pntr++ = (parameters->list)[pnum - 1][pc++];
}
@@ -322,7 +322,7 @@ get_parameter_strings(int number,char * macro_name)
break;
case '#':
- /* uh oh, I have a paramter reference inside a paramter */
+ /* uh oh, I have a parameter reference inside a parameter */
/* get the number */
if (parameters == NULL) {
@@ -347,7 +347,7 @@ get_parameter_strings(int number,char * macro_name)
pnum = atoi(pnum_chars);
pc = 0;
- /* Now copy the paramter */
+ /* Now copy the parameter */
while ((parameters->list)[pnum - 1][pc] != '\0')
*buffer_pntr++ = (parameters->list)[pnum - 1][pc++];